Package: GeneBreak
Type: Package
Version: 1.42.0
Title: Gene Break Detection
Author: Evert van den Broek, Stef van Lieshout
Maintainer: Evert van den Broek <vandenbroek.evert@gmail.com>
Imports: graphics, methods
Depends: R(>= 3.2), QDNAseq, CGHcall, CGHbase, GenomicRanges
URL: https://github.com/stefvanlieshout/GeneBreak
Description: Recurrent breakpoint gene detection on copy number
        aberration profiles.
License: GPL-2
biocViews: aCGH, CopyNumberVariation, DNASeq, Genetics, Sequencing,
        WholeGenome, Visualization
LazyData: FALSE
git_url: https://git.bioconductor.org/packages/GeneBreak
git_branch: RELEASE_3_23
git_last_commit: a2fac37
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:13:53 UTC; biocbuild
Built: R 4.6.0; ; 2026-04-29 04:44:08 UTC; unix
